@@ -16,8 +16,6 @@
 Module to enable color terminal output
 """
 
-from __future__ import print_function
-
 import string
 import os
 
@@ -87,7 +85,6 @@ enable_ANSI_colors()
 if os.name in ['nt']:
     disable_ANSI_colors()
 
-# TODO: Is this needed in addition to enable_/disable_ functions?
 _color_on = True
 
 
@@ -125,7 +122,7 @@ def sanitize(msg):
     return msg
 
 
-def fmt(msg):
+def fmt(msg, reset=True):
     """Replaces color annotations with ansi escape sequences"""
     global _ansi
     msg = msg.replace('@!', '@{boldon}')
@@ -133,7 +130,7 @@ def fmt(msg):
     msg = msg.replace('@_', '@{ulon}')
     msg = msg.replace('@|', '@{reset}')
     t = ColorTemplate(msg)
-    return t.substitute(_ansi) + ansi('reset')
+    return t.substitute(_ansi) + (ansi('reset') if reset else '')
 
 
 def test_colors():
@@ -156,7 +153,7 @@ class ColorMapper(object):
     functionality to convert them into colorized version.
     """
 
-    # This map translates more human reable format strings into colorized versions
+    # This map translates more human readable format strings into colorized versions
     default_color_translation_map = {
         # 'output': 'colorized_output'
         '': fmt('@!' + sanitize('') + '@|')
@@ -165,7 +162,7 @@ class ColorMapper(object):
     def __init__(self, color_map={}):
         """Create a color mapper with a given map.
 
-        :param color_map: A dictionary of format strings and colorized verisons
+        :param color_map: A dictionary of format strings and colorized versions
         :type color_map: dict
         """
         self.color_map = ColorMapper.default_color_translation_map
@@ -174,7 +171,7 @@ class ColorMapper(object):
     def clr(self, key):
         """Returns a colorized version of the string given.
 
-        This is occomplished by either returning a hit from the color translation
+        This is accomplished by either returning a hit from the color translation
         map or by calling :py:func:`fmt` on the string and returning it.
 
         :param key: string to be colorized
