@@ -19,7 +19,7 @@ from catkin_tools.terminal_color import fmt
 from catkin_tools.terminal_color import sanitize
 from catkin_tools.terminal_color import ColorMapper
 
-# This map translates more human reable format strings into colorized versions
+# This map translates more human readable format strings into colorized versions
 _color_translation_map = {
     # 'output': 'colorized_output'
     '': fmt('@!' + sanitize('') + '@|'),
@@ -42,6 +42,9 @@ _color_translation_map = {
     "Finished <== {package:<":
     fmt("@!@{kf}Finished@| @{gf}<==@| @{cf}{package:<").rstrip(ansi('reset')),
 
+    "Failed <== {package:<":
+    fmt("@!@{rf}Failed@|   @{gf}<==@| @{cf}{package:<").rstrip(ansi('reset')),
+
     "} [ {time} ]":
     fmt("}@| [ @{yf}{time}@| ]"),
 
@@ -54,6 +57,9 @@ _color_translation_map = {
     "[{0}/{1} Active | {2}/{3} Completed]":
     fmt("[@!@{gf}{0}@|/@{gf}{1}@| Active | @!@{gf}{2}@|/@{gf}{3}@| Completed]"),
 
+    "[{0}/{1} Jobs | {2}/{3} Active | {4}/{5} Completed]":
+    fmt("[@!@{gf}{0}@|/@{gf}{1}@| Jobs | @!@{gf}{2}@|/@{gf}{3}@| Active | @!@{gf}{4}@|/@{gf}{5}@| Completed]"),
+
     "[!{package}] ":
     fmt("[@!@{rf}!@|@{cf}{package}@|] "),
 }
@@ -61,34 +67,3 @@ _color_translation_map = {
 color_mapper = ColorMapper(_color_translation_map)
 
 clr = color_mapper.clr
-
-
-def colorize_cmake(line):
-    """Colorizes output from CMake
-
-    :param line: one, new line terminated, line from `cmake` which needs coloring.
-    :type line: str
-    """
-    cline = sanitize(line)
-    if line.startswith('-- '):
-        cline = '@{cf}-- @|' + cline[len('-- '):]
-        if ':' in cline:
-            split_cline = cline.split(':')
-            cline = split_cline[0] + ':@{yf}' + ':'.join(split_cline[1:]) + '@|'
-    if line.lower().startswith('warning'):
-        # WARNING
-        cline = fmt('@{yf}') + cline
-    if line.startswith('CMake Warning'):
-        # CMake Warning...
-        cline = cline.replace('CMake Warning', '@{yf}@!CMake Warning@|')
-    if line.startswith('ERROR:'):
-        # ERROR:
-        cline = cline.replace('ERROR:', '@!@{rf}ERROR:@|')
-    if line.startswith('CMake Error'):
-        # CMake Error...
-        cline = cline.replace('CMake Error', '@{rf}@!CMake Error@|')
-    if line.startswith('Call Stack (most recent call first):'):
-        # CMake Call Stack
-        cline = cline.replace('Call Stack (most recent call first):',
-                              '@{cf}@_Call Stack (most recent call first):@|')
-    return fmt(cline)
